summaryrefslogtreecommitdiffstats
path: root/kword/KWResizeTableDia.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /kword/KWResizeTableDia.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kword/KWResizeTableDia.h')
-rw-r--r--kword/KWResizeTableDia.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kword/KWResizeTableDia.h b/kword/KWResizeTableDia.h
index f1512269..7ca65eae 100644
--- a/kword/KWResizeTableDia.h
+++ b/kword/KWResizeTableDia.h
@@ -39,12 +39,12 @@ class KWResizeTableDia : public KDialogBase
public:
/**
* Constructor.
* @param tqparent tqparent widget for dialog
* @param table the table to do the resizes on
* @param doc the document this table belongs to, for undo information
* @param resizeColumn the initial column that the user can resize.
*/
- KWResizeTableDia( TQWidget *tqparent, KWTableFrameSet *table, KWDocument *doc, int resizeColumn);
+ KWResizeTableDia( TQWidget *parent, KWTableFrameSet *table, KWDocument *doc, int resizeColumn);
protected:
void setupTab1( int resizeColumn);
@@ -39,12 +39,12 @@ class KWResizeTableDia : public KDialogBase
/**
* Constructor.
- * @param tqparent tqparent widget for dialog
+ * @param parent parent widget for dialog
* @param table the table to do the resizes on
* @param doc the document this table belongs to, for undo information